Module: Finance

Defined in:
lib/finance.rb,
lib/finance/rates.rb,
lib/finance/cashflows.rb,
lib/finance/transaction.rb,
lib/finance/amortization.rb

Overview

The Finance module adheres to the following conventions for financial calculations:

  • Positive values represent cash inflows (money received); negative values represent cash outflows (payments).
  • principal represents the outstanding balance of a loan or annuity.
  • rate represents the interest rate per period.

Defined Under Namespace

Modules: Cashflow Classes: Amortization, Interest, Payment, Rate, Transaction